@@ -191,6 +191,13 @@ def __fragment_to_path(scheme, host, path, fragment):
     ):
         return "/g/" + fragment[len("!topic/") :].replace("/", "/c/", 1)
 
+    if (
+        host == "groups.google.com"
+        and path.startswith("/forum")
+        and fragment.startswith("!forum/")
+    ):
+        return "/g/" + fragment[len("!forum/") :]
+
     if (
         host == "groups.google.com"
         and path.startswith("/forum")
@@ -285,10 +292,10 @@ def __canonical_youtube(
                 video_id = path_parts[-1]
 
         if video_id:
-            return "youtu.be", "/" + video_id, []
+            return "youtu.be", "/" + video_id.lower(), []
 
     if host_remap and host == "dev.tube" and path.startswith("/video/"):
-        return "youtu.be", path[len("/video") :], []
+        return "youtu.be", path[len("/video") :].lower(), []
 
 
 def __canonical_medium(
@@ -594,7 +601,14 @@ def cleanurl(
     else:
         u = url
 
+    if u.scheme == "about" and u.path == "reader":
+        pq = urlparse.parse_qs(u.query, keep_blank_values=True)
+        urls = pq.get("url")
+        if urls:
+            return cleanurl(urls[0], generic, respect_semantics, host_remap)
+
     scheme = u.scheme
+
     host = __canonical_host(u.netloc, respect_semantics)
     path = __canonical_path(scheme, u.path, respect_semantics)
     parsed_query = __canonical_query(u.query, respect_semantics)
